within ;
model DryFriction "Linear 1D dry friction element"
  extends
    Modelica.Mechanics.Translational.Interfaces.PartialCompliantWithRelativeStates;

  import SI = Modelica.SIunits;

  parameter SI.Force N "normal force";
  parameter SI.Velocity vAdhesion "adhesion velocity";
  parameter SI.Velocity vSlide "sliding velocity";
  parameter Real mu_A "friction coefficient at adhesion";
  parameter Real mu_S "friction coefficient at sliding";

equation
  f =  N*PlanarMechanicsV1.Utilities.TripleS_Func(vAdhesion,vSlide,mu_A,mu_S,v_rel);

  annotation (Icon(graphics={
        Rectangle(
          extent={{-40,40},{60,12}},
          pattern=LinePattern.None,
          fillColor={175,175,175},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-60,-12},{40,-40}},
          pattern=LinePattern.None,
          fillColor={175,175,175},
          fillPattern=FillPattern.Solid),
        Line(
          points={{-90,0},{-60,0},{-60,-40},{40,-40},{40,-12}},
          pattern=LinePattern.None,
          smooth=Smooth.None),
        Line(
          points={{90,0},{60,0},{60,40},{-40,40},{-40,12}},
          pattern=LinePattern.None,
          smooth=Smooth.None),
        Text(
          extent={{0,116},{0,56}},
          textString="%name",
          lineColor={0,0,255})}), uses(Modelica(version="3.1")));
end DryFriction;
